/**
 * @file lindmxd_config.h
 * @author Florian Schmitt <florian.schmitt@qikgrp.com>
 * ----------------------------------------------------------------------------
 *    L I N    D M X    S E R V E R
 * ----------------------------------------------------------------------------
 * (c) Florian Schmitt / 2012-2014
 * License GPLv3+: GNU GPL Version 3 
 * or higher <http://gnu.org/licenses/gpl.html>
 * This code comes with ABSOLUTELY NO WARRANTY. This is free software, and 
 * you are welcome to redistribute it under certain conditions.
 * ----------------------------------------------------------------------------
 * This contains a basic data structure for storing configuration setups and 
 * also some basic operations to load and handle it.
**/
#ifndef LINDMXD_CONFIG_H
#define LINDMXD_CONFIG_H

#define LINDMXD_CONFIG_BUFLEN      512
#define LINDMXD_CONFIG_SUCCESS       1
#define LINDMXD_CONFIG_ERR_PARSE    -1
#define LINDMXD_CONFIG_ERR_FILE     -2
#define LINDMXD_CONFIG_ERR_INTERNAL -3
#define LINDMXD_CONFIG_ERR_MAXREK   -4

typedef struct lindmxd_config {
	/* Basic program settings */
	int channels;
	int debug;
	int zero;
	/* Interface name */
	const char *interface;
	/* Settings for networking interfaces */
	char if_host[LINDMXD_CONFIG_BUFLEN];
	int if_port;
	/* Status and daemon related informations */
	const char *daemon_name;
	const char *program_name;
	/* Syslog log up to priority */
	int log_upto;
	int log_facility;
	/* Where to run the tcp instance */
	int port;
} lindmxd_config_t;


/* Initializes default values */
void lindmxd_config_init_defaults(lindmxd_config_t*);

/* Initializes default values */
void lindmxd_config_init_defaults(lindmxd_config_t*);

/* Parses and loads config file */
int lindmxd_config_parse(lindmxd_config_t*, const char*, int);

/* Get last error as string */
const char *lindmxd_config_geterr();


#endif /* LINDMXD_CONFIG_H */
